@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/literals.html)
 
 Usage::
 
@@ -19,18 +19,10 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = (
-    "ListRetainedMessagesPaginatorName",
-    "IoTDataPlaneServiceName",
-    "ServiceName",
-    "ResourceServiceName",
-    "PaginatorName",
-    "RegionName",
-)
+__all__ = ("ListRetainedMessagesPaginatorName", "ServiceName", "PaginatorName")
 
 
 ListRetainedMessagesPaginatorName = Literal["list_retained_messages"]
-IoTDataPlaneServiceName = Literal["iot-data"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -319,36 +311,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal["list_retained_messages"]
-RegionName = Literal[
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "me-south-1",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
